local _G = _G
local CM = ChatMonitor
local AceConfig = ChatMonitor.LS("AceConfig-3.0")
local AceConfigDialog = ChatMonitor.LS("AceConfigDialog-3.0")
local AceDBOptions = ChatMonitor.LS("AceDBOptions-3.0")
local L = CM.L
local CreateFrame, ipairs = CreateFrame, ipairs

--First visible frame
local function CreateMainPanel()
	local frame = CreateFrame("Frame", "ChatMonitorOptionsMain")
	local title = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	local version = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	local author = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetFormattedText("|T%s:%d|t %s", "Interface\\GossipFrame\\ChatBubbleGossipIcon", 16, "Chat Monitor")
	title:SetPoint("CENTER", frame, "CENTER", 0, 170)
	version:SetText(_G.GAME_VERSION_LABEL .. " " .. GetAddOnMetadata("ChatMonitor", "Version"))
	version:SetPoint("CENTER", frame, "CENTER", 0, 130)
	author:SetText(L["Author"] .. ": Deepac")
	author:SetPoint("CENTER", frame, "CENTER", 0, 100)
	return frame
end

local function GetTimeFormats()
	local formats = {}
	f = CM.timeformats
	
	for idx, form in pairs(f) do formats[idx] = date(form) end
	
	return formats
end

local OptionsPanel = {
	order = 1,
	type = "group",
	name = _G.MAIN_MENU,
	inline = false,
	args = {
		channels = {
			order = 1,
			name = _G.CHANNELS,
			type = "group",
			inline = false,
			args = {},
		},
		professions = {
			order = 2,
			name = _G.TRADE_SKILLS,
			type = "group",
			inline = false,
			args = {},
		},
		classes = {
			order = 3,
			name = L["Classes"],
			type = "group",
			inline = false,
			args = {},
		},
		roles = {
			order = 4,
			name = L["Roles"],
			type = "group",
			inline = false,
			args = {},
		},
		lfg = {
			order = 5,
			name = _G.LFG_TITLE,
			type = "group",
			inline = false,
			args = {
				lfgc = {
					order = 1,
					name = _G.LFG_TITLE,
					type = "toggle",
					width = "full",
					get = function() return CM.db.char.lfgc end,
					set = function(info, value) CM.db.char.lfgc = value end,
				},
				lfgccolour = {
					order = 2,
					name = _G.COLOR,
					type = "color",
					hasAlpha = true,
					hidden = function() return not CM.db.char.lfgc end,
					get = function() return CM:HexToRGB(CM.db.profile.lfgccolour) end,
					set = function(info, r, g, b, a) CM.db.profile.lfgccolour = CM:RGBToHex(r, g, b, a) end,
				},
				lfgcsound = {
					order = 3,
					name = _G.SOUND_LABEL,
					type = "select",
					dialogControl = "LSM30_Sound",
					values = CM.LSM:HashTable(CM.LSM.MediaType.SOUND),
					hidden = function() return not CM.db.char.lfgc end,
					get = function() return CM.db.profile.lfgcsound end,
					set = function(info, value) CM.db.profile.lfgcsound = value end,
				},
				lfgckeywords = {
					order = 4,
					name = L["Keywords"],
					type = "input",
					width = "full",
					multiline = 2,
					hidden = function() return not CM.db.char.lfgc end,
					get = function() return CM.db.profile.lfgclist end,
					set = function(info, value) CM.db.profile.lfgclist = value end,
				},
			},
		},
		lfm = {
			order = 6,
			name = _G.LFM_TITLE,
			type = "group",
			inline = false,
			args = {
				lfm = {
					order = 1,
					name = _G.LFM_TITLE,
					type = "toggle",
					width = "full",
					get = function() return CM.db.char.lfm end,
					set = function(info, value) CM.db.char.lfm = value end,
				},
				lfmcolour = {
					order = 2,
					name = _G.COLOR,
					type = "color",
					hasAlpha = true,
					hidden = function() return not CM.db.char.lfm end,
					get = function() return CM:HexToRGB(CM.db.profile.lfmcolour) end,
					set = function(info, r, g, b, a) CM.db.profile.lfmcolour = CM:RGBToHex(r, g, b, a) end,
				},
				lfmsound = {
					order = 3,
					name = _G.SOUND_LABEL,
					type = "select",
					dialogControl = "LSM30_Sound",
					values = CM.LSM:HashTable(CM.LSM.MediaType.SOUND),
					hidden = function() return not CM.db.char.lfm end,
					get = function() return CM.db.profile.lfmsound end,
					set = function(info, value) CM.db.profile.lfmsound = value end,
				},
				lfmkeywords = {
					order = 4,
					name = L["Keywords"],
					type = "input",
					width = "full",
					multiline = 2,
					hidden = function() return not CM.db.char.lfm end,
					get = function() return CM.db.profile.lfmlist end,
					set = function(info, value) CM.db.profile.lfmlist = value end,
				},
			},
		},
		selling = {
			order = 7,
			name = L["Selling"],
			type = "group",
			inline = false,
			args = {
				selling = {
					order = 1,
					name = L["Selling"],
					type = "toggle",
					width = "full",
					get = function() return CM.db.char.wts end,
					set = function(info, value) CM.db.char.wts = value end,
				},
				sellingcolour = {
					order = 2,
					name = _G.COLOR,
					type = "color",
					hasAlpha = true,
					hidden = function() return not CM.db.char.wts end,
					get = function() return CM:HexToRGB(CM.db.profile.wtscolour) end,
					set = function(info, r, g, b, a) CM.db.profile.wtscolour = CM:RGBToHex(r, g, b, a) end,
				},
				sellingsound = {
					order = 3,
					name = _G.SOUND_LABEL,
					type = "select",
					dialogControl = "LSM30_Sound",
					values = CM.LSM:HashTable(CM.LSM.MediaType.SOUND),
					hidden = function() return not CM.db.char.wts end,
					get = function() return CM.db.profile.wtssound end,
					set = function(info, value) CM.db.profile.wtssound = value end,
				},
				sellingkeywords = {
					order = 4,
					name = L["Keywords"],
					type = "input",
					width = "full",
					multiline = 2,
					hidden = function() return not CM.db.char.wts end,
					get = function() return CM.db.profile.wtslist end,
					set = function(info, value) CM.db.profile.wtslist = value end,
				},
			},
		},
		buying = {
			order = 8,
			name = L["Buying"],
			type = "group",
			inline = false,
			args = {
				buying = {
					order = 1,
					name = L["Buying"],
					type = "toggle",
					width = "full",
					get = function() return CM.db.char.wtb end,
					set = function(info, value) CM.db.char.wtb = value end,
				},
				buyingcolour = {
					order = 2,
					name = _G.COLOR,
					type = "color",
					hasAlpha = true,
					hidden = function() return not CM.db.char.wtb end,
					get = function() return CM:HexToRGB(CM.db.profile.wtbcolour) end,
					set = function(info, r, g, b, a) CM.db.profile.wtbcolour = CM:RGBToHex(r, g, b, a) end,
				},
				buyingsound = {
					order = 3,
					name = _G.SOUND_LABEL,
					type = "select",
					dialogControl = "LSM30_Sound",
					values = CM.LSM:HashTable(CM.LSM.MediaType.SOUND),
					hidden = function() return not CM.db.char.wtb end,
					get = function() return CM.db.profile.wtbsound end,
					set = function(info, value) CM.db.profile.wtbsound = value end,
				},
				buyingkeywords = {
					order = 4,
					name = L["Keywords"],
					type = "input",
					width = "full",
					multiline = 2,
					hidden = function() return not CM.db.char.wtb end,
					get = function() return CM.db.profile.wtblist end,
					set = function(info, value) CM.db.profile.wtblist = value end,
				},
			},
		},
		guild = {
			order = 9,
			name = _G.GUILD,
			type = "group",
			inline = false,
			args = {
				guild = {
					order = 1,
					name = L["Advertising"],
					type = "toggle",
					width = "full",
					get = function() return CM.db.char.guild end,
					set = function(info, value) CM.db.char.guild = value end,
				},
				guildcolour = {
					order = 2,
					name = _G.COLOR,
					type = "color",
					hasAlpha = true,
					hidden = function() return not CM.db.char.guild end,
					get = function() return CM:HexToRGB(CM.db.profile.guildcolour) end,
					set = function(info, r, g, b, a) CM.db.profile.guildcolour = CM:RGBToHex(r, g, b, a) end,
				},
				guildsound = {
					order = 3,
					name = _G.SOUND_LABEL,
					type = "select",
					dialogControl = "LSM30_Sound",
					values = CM.LSM:HashTable(CM.LSM.MediaType.SOUND),
					hidden = function() return not CM.db.char.guild end,
					get = function() return CM.db.profile.guildsound end,
					set = function(info, value) CM.db.profile.guildsound = value end,
				},
				guildkeywords = {
					order = 4,
					name = L["Keywords"],
					type = "input",
					width = "full",
					multiline = 2,
					hidden = function() return not CM.db.char.guild end,
					get = function() return CM.db.profile.guildlist end,
					set = function(info, value) CM.db.profile.guildlist = value end,
				},
				lfguild = {
					order = 5,
					name = L["Looking for"],
					type = "toggle",
					width = "full",
					get = function() return CM.db.char.lfguild end,
					set = function(info, value) CM.db.char.lfguild = value end,
				},
				lfguildcolour = {
					order = 6,
					name = _G.COLOR,
					type = "color",
					hasAlpha = true,
					hidden = function() return not CM.db.char.lfguild end,
					get = function() return CM:HexToRGB(CM.db.profile.lfguildcolour) end,
					set = function(info, r, g, b, a) CM.db.profile.lfguildcolour = CM:RGBToHex(r, g, b, a) end,
				},
				lfguildsound = {
					order = 7,
					name = _G.SOUND_LABEL,
					type = "select",
					dialogControl = "LSM30_Sound",
					values = CM.LSM:HashTable(CM.LSM.MediaType.SOUND),
					hidden = function() return not CM.db.char.lfguild end,
					get = function() return CM.db.profile.lfguildsound end,
					set = function(info, value) CM.db.profile.lfguildsound = value end,
				},
				lfguildkeywords = {
					order = 8,
					name = L["Keywords"],
					type = "input",
					width = "full",
					multiline = 2,
					hidden = function() return not CM.db.char.lfguild end,
					get = function() return CM.db.profile.lfguildlist end,
					set = function(info, value) CM.db.profile.lfguildlist = value end,
				},
			},
		},
		cus = {
			order = 10,
			name = _G.CUSTOM,
			type = "group",
			inline = false,
			args = {
				cus = {
					order = 1,
					name = _G.CUSTOM,
					type = "toggle",
					width = "full",
					get = function() return CM.db.char.cus end,
					set = function(info, value) CM.db.char.cus = value end,
				},
				cuscolour = {
					order = 2,
					name = _G.COLOR,
					type = "color",
					hasAlpha = true,
					hidden = function() return not CM.db.char.cus end,
					get = function() return CM:HexToRGB(CM.db.profile.cuscolour) end,
					set = function(info, r, g, b, a) CM.db.profile.cuscolour = CM:RGBToHex(r, g, b, a) end,
				},
				cussound = {
					order = 3,
					name = _G.SOUND_LABEL,
					type = "select",
					dialogControl = "LSM30_Sound",
					values = CM.LSM:HashTable(CM.LSM.MediaType.SOUND),
					hidden = function() return not CM.db.char.cus end,
					get = function() return CM.db.profile.cussound end,
					set = function(info, value) CM.db.profile.cussound = value end,
				},
				cuskeywords = {
					order = 4,
					name = L["Keywords"],
					type = "input",
					width = "full",
					multiline = 2,
					hidden = function() return not CM.db.char.cus end,
					get = function() return CM.db.profile.cuslist end,
					set = function(info, value) CM.db.profile.cuslist = value end,
				},
			},
		},
		appearance = {
			order = 11,
			name = _G.APPEARANCE_LABEL,
			type = "group",
			inline = false,
			args = {
				enabled = {
					order = 1,
					type = "toggle",
					name = _G.VIDEO_OPTIONS_ENABLED,
					width = "full",
					get = function() return CM.db.char.enabled end,
					set =
						function(info, value)
							CM.db.char.enabled = value
							CM:CheckChannels()
						end,
				},
				sp0 = {
					order = 2,
					name = "\n",
					type = "description",
				},
				bgcolour = {
					order = 3,
					type = "color",
					name = L["Background color"],
					hasAlpha = true,
					hidden = function() return IsAddOnLoaded("ElvUI") end,
					get = function() return CM:HexToRGB(CM.db.profile.backdropbackground) end,
					set =
						function(info, r, g, b, a)
							CM.db.profile.backdropbackground = CM:RGBToHex(r, g, b, a)
							ChatMonitorMain:SetBackdropColor(r, g, b, a)
						end,
				},
				bordcolour = {
					order = 4,
					type = "color",
					name = _G.EMBLEM_BORDER_COLOR,
					hasAlpha = true,
					hidden = function() return IsAddOnLoaded("ElvUI") end,
					get = function() return CM:HexToRGB(CM.db.profile.backdropborder) end,
					set =
						function(info, r, g, b, a)
							CM.db.profile.backdropborder = CM:RGBToHex(r, g, b, a)
							ChatMonitorMain:SetBackdropBorderColor(r, g, b, a)
						end,
				},
				sp1 = {
					order = 5,
					name = "\n",
					hidden = function() return IsAddOnLoaded("ElvUI") end,
					type = "description",
				},
				font = {
					order = 6,
					type = "select",
					name = L["Font"],
					dialogControl = "LSM30_Font",
					values = CM.LSM:HashTable(CM.LSM.MediaType.FONT),
					get = function() return CM.db.profile.font end,
					set =
						function(info, name)
							local font = CM.LSM:Fetch(CM.LSM.MediaType.FONT, name)
							CM.db.profile.font = name
							ChatMonitorScroll:SetFont(font, CM.db.profile.fontsize)
						end,
				},
				fontsize = {
					order = 7,
					type = "range",
					width = "full",
					min = 4,
					softMin = 4,
					max = 28,
					softMax = 28,
					step = 1,
					bigStep = 1,
					name = _G.FONT_SIZE,
					get = function() return CM.db.profile.fontsize end,
					set =
						function(info, value)
							CM.db.profile.fontsize = value
							local font = ChatMonitorScroll:GetFont()
							ChatMonitorScroll:SetFont(font, value)
						end,
				},				
				sp2 = {
					order = 8,
					name = "\n",
					type = "description",
				},
				fade = {
					order = 9,
					type = "range",
					width = "full",
					min = 1,
					softMin = 1,
					max = 10,
					softMax = 10,
					step = 1,
					bigStep = 1,
					name = L["Message fade time in minutes"],
					get = function() return CM.db.profile.fadetime / 60 end,
					set =
						function(info, value)
							CM.db.profile.fadetime = value * 60
							ChatMonitorScroll:SetFadeDuration(value * 60)
						end,
				},
				sp3 = {
					order = 10,
					name = "\n",
					type = "description",
				},				
				ts = {
					order = 11,
					type = "toggle",
					name = _G.SHOW_TIMESTAMP,
					get = function() return CM.db.profile.showts end,
					set = function(info, value) CM.db.profile.showts = value end,
				},
				tscolour = {
					order = 12,
					type = "color",
					name = _G.COLOR,
					hasAlpha = true,
					hidden = function() return not CM.db.profile.showts end,
					get = function() return CM:HexToRGB(CM.db.profile.timestampcolour) end,
					set = function(info, r, g, b, a) CM.db.profile.timestampcolour = CM:RGBToHex(r, g, b, a) end,
				},
				tsformat = {
					order = 13,
					type = "select",
					name = L["Timestamp format"],
					values = GetTimeFormats(),
					style = "radio",
					hidden = function() return not CM.db.profile.showts end,
					get = function() return CM.db.profile.tsformat end,
					set = function(info, value) CM.db.profile.tsformat = value end,
				},
				hidescroll = {
					order = 14,
					type = "toggle",
					width = "full",
					name = L["Hide scrollbar"],
					get = function() return CM.db.profile.hidescroll end,
					set =
						function(info, value)
							CM.db.profile.hidescroll = value
							if value then
								ChatMonitorSlider:Hide()
							else
								ChatMonitorSlider:Show()
							end
						end,
				},
				tradeonly = {
					order = 15,
					type = "toggle",
					width = "full",
					name = L["Only display when the Trade channel is enabled"],
					get = function() return CM.db.profile.tradeonly end,
					set =
						function(info, value)
							CM.db.profile.tradeonly = value
							CM:CheckChannels()
						end,
				},
				lock = {
					order = 16,
					type = "toggle",
					width = "full",
					name = _G.LOCK_FOCUS_FRAME,
					get = function() return CM.db.profile.locked end,
					set = function(info, value) CM.db.profile.locked = value end,
				},
				disresize = {
					order = 17,
					type = "toggle",
					width = "full",
					name = _G.WINDOW_LOCK,
					get = function() return CM.db.profile.resizelock end,
					set =
						function(info, value)
							CM.db.profile.resizelock = value
							if value then CM.dragframe:Hide()
							else CM.dragframe:Show() end
						end,
				},
			},
		},
		other = {
			order = 12,
			name = _G.OTHER,
			type = "group",
			inline = false,
			args = {
				distance = {
					order = 1,
					type = "range",
					name = L["Accuracy"],
					min = 0,
					max = 5,
					isPercent = false,
					step = 1,
					width = "full",
					get = function() return math.abs(CM.db.profile.maxdistance - 5) end,
					set = function(info, value) CM.db.profile.maxdistance = math.abs(value - 5) end,
				},
				sp1 = {
					order = 2,
					name = "\n",
					type = "description",
				},
				info = {
					order = 3,
					name = L["Adjust how close a match the keywords are. Ignored for pattern matching or words of less than 4 letters."],
					type = "description",
				},
			},
		},
		help = {
			order = 13,
			name = _G.GAMEMENU_HELP,
			type = "group",
			inline = false,
			args = {
				help = {
					order = 1,
					name = L["Lua patterns can be used as keywords if they are enclosed between / marks e.g."],
					type = "description",
				},
				sp1 = {
					order = 2,
					name = "\n",
					type = "description",
				},
				help1 = {
					order = 3,
					name = "/<.+>/",
					type = "description",
				},
				sp2 = {
					order = 4,
					name = "\n",
					type = "description",
				},
				help2 = {
					order = 5,
					name = L["will match any text contained within < > marks."],
					type = "description",
				},
				sp3 = {
					order = 6,
					name = "\n",
					type = "description",
				},
				help3 = {
					order = 7,
					name = L["For help with Lua pattern matching, see: https://www.lua.org/pil/20.2.html"],
					type = "description",
				},
			},
		},
	},
}

local function AddRoles()
	local roles = {heal = _G.HEALER, dps = _G.STAT_DPS_SHORT, tank = _G.TANK, mel = _G.MELEE, rng = _G.RANGED, cc = L["Crowd control"]}
	local position = 1

	for role, rolename in pairs(roles) do
		OptionsPanel.args.roles.args[role] = {order = position, name = rolename, type = "toggle", width = "full",
			get = function() return CM.db.char[role] end,
			set = function(info, value) CM.db.char[role] = value end}
		position = position + 1
		OptionsPanel.args.roles.args[format("%scolour", role)] = {order = position, name = _G.COLOR, type = "color", hasAlpha = true,
			hidden = function() return not CM.db.char[role] end,
			get = function() return CM:HexToRGB(CM.db.profile[format("%scolour", role)]) end,
			set = function(info, r, g, b, a) CM.db.profile[format("%scolour", role)] = CM.RGBToHex(r, g, b, a) end}
		position = position + 1
		OptionsPanel.args.roles.args[format("%ssound", role)] = {order = position, name = _G.SOUND_LABEL, type = "select", dialogControl = "LSM30_Sound",
			values = CM.LSM:HashTable(CM.LSM.MediaType.SOUND),
			hidden = function() return not CM.db.char[role] end,
			get = function() return CM.db.profile[format("%ssound", role)] end,
			set = function(info, value) CM.db.profile[format("%ssound", role)] = value end}
		position = position + 1
		OptionsPanel.args.roles.args[format("%skeywords", role)] = {order = position, name = L["Keywords"], type = "input", width = "full", multiline = 2,
			hidden = function() return not CM.db.char[role] end,
			get = function() return CM.db.profile[format("%slist", role)] end,
			set = function(info, value) CM.db.profile[format("%slist", role)] = value end}
		position = position + 1
	end
end

local function AddClasses()
	local classes = {}
	local position = 1

	FillLocalizedClassList(classes)
	for token, localname in pairs(classes) do
		local lname = string.lower(token)
		OptionsPanel.args.classes.args[lname] = {order = position, name = localname, type = "toggle", width = "full",
			get = function() return CM.db.char[lname] end,
			set = function(info, value) CM.db.char[lname] = value end}
		position = position + 1
		OptionsPanel.args.classes.args[format("%scolour", lname)] = {order = position, name = _G.COLOR, type = "color", hasAlpha = true,
			hidden = function() return not CM.db.char[lname] end,
			get = function() return CM:HexToRGB(CM.db.profile[format("%scolour", lname)]) end,
			set = function(info, r, g, b, a) CM.db.profile[format("%scolour", lname)] = CM.RGBToHex(r, g, b, a) end}
		position = position + 1
		OptionsPanel.args.classes.args[format("%ssound", lname)] = {order = position, name = _G.SOUND_LABEL, type = "select", dialogControl = "LSM30_Sound",
			values = CM.LSM:HashTable(CM.LSM.MediaType.SOUND),
			hidden = function() return not CM.db.char[lname] end,
			get = function() return CM.db.profile[format("%ssound", lname)] end,
			set = function(info, value) CM.db.profile[format("%ssound", lname)] = value end}
		position = position + 1
		OptionsPanel.args.classes.args[format("%skeywords", lname)] = {order = position, name = L["Keywords"], type = "input", width = "full", multiline = 2,
			hidden = function() return not CM.db.char[lname] end,
			get = function() return CM.db.profile[format("%slist", lname)] end,
			set = function(info, value) CM.db.profile[format("%slist", lname)] = value end}
		position = position + 1
	end
end

local function AddChannels()
	local chans = {general = _G.GENERAL, trade = _G.TRADE, guild = _G.GUILD, lfg = _G.LFG_TITLE} --, custom = _G.CUSTOM}
	local position = 1

	for chan, channame in pairs(chans) do
		OptionsPanel.args.channels.args[chan] = {order = position, name = channame, type = "toggle", width = "full",
			get = function() return CM.db.char[format("chan%s", chan)] end,
			set = function(info, value) CM.db.char[format("chan%s", chan)] = value CM:CheckChannels() end}
		position = position + 1
	end
end

local function AddProfessions()
	local profs = {alc = L["Alchemy"], bs = L["Blacksmithing"], enc = L["Enchanting"], eng = L["Engineering"],
		ins = L["Inscription"], js = L["Jewelcrafting"], lw = L["Leatherworking"], tlr = L["Tailoring"]}
	local position = 1

	for prof, profname in pairs(profs) do
		OptionsPanel.args.professions.args[prof] = {order = position, name = profname, type = "toggle", width = "full",
			get = function() return CM.db.char[prof] end,
			set = function(info, value) CM.db.char[prof] = value end}
		position = position + 1
		OptionsPanel.args.professions.args[format("%scolour", prof)] = {order = position, name = _G.COLOR, type = "color", hasAlpha = true,
			hidden = function() return not CM.db.char[prof] end,
			get = function() return CM:HexToRGB(CM.db.profile[format("%scolour", prof)]) end,
			set = function(info, r, g, b, a) CM.db.profile[format("%scolour", prof)] = CM.RGBToHex(r, g, b, a) end}
		position = position + 1
		OptionsPanel.args.professions.args[format("%ssound", prof)] = {order = position, name = _G.SOUND_LABEL, type = "select", dialogControl = "LSM30_Sound",
			values = CM.LSM:HashTable(CM.LSM.MediaType.SOUND),
			hidden = function() return not CM.db.char[prof] end,
			get = function() return CM.db.profile[format("%ssound", prof)] end,
			set = function(info, value) CM.db.profile[format("%ssound", prof)] = value end}
		position = position + 1
		OptionsPanel.args.professions.args[format("%skeywords", prof)] = {order = position, name = L["Keywords"], type = "input", width = "full", multiline = 2,
			hidden = function() return not CM.db.char[prof] end,
			get = function() return CM.db.profile[format("%slist", prof)] end,
			set = function(info, value) CM.db.profile[format("%slist", prof)] = value end}
		position = position + 1
	end
end

--respond to Default button/Profile reset
function ChatMonitor:ProfileReset() CM.db.ResetProfile() end

--Setup options
function CM:CreateOptions()
	local mainPanel = CreateMainPanel()
	mainPanel.name = "Chat Monitor"
	InterfaceOptions_AddCategory(mainPanel)
	--make sure Speak Up's reset sub is called in response to a profile reset
	--ChatMonitor.db.RegisterCallback(ChatMonitor, "OnProfileReset", "ProfileReset")
	AddChannels()
	AddProfessions()
	AddClasses()
	AddRoles()
	AceConfig:RegisterOptionsTable("ChatMonitorOptions", OptionsPanel)
	AceConfig:RegisterOptionsTable("ChatMonitorProfiles", AceDBOptions:GetOptionsTable(CM.db))
	CM.options = AceConfigDialog:AddToBlizOptions("ChatMonitorOptions", _G.MAIN_MENU, "Chat Monitor")
	--make sure Speak Up's reset function is call in response to the user clicking the Default button
	--ChatMonitor.options.default = function() ChatMonitor.db:ResetProfile() end
	AceConfigDialog:AddToBlizOptions("ChatMonitorProfiles", L["Profiles"], "Chat Monitor")
end
